==> moodle-2.0.10_20120721.zip: moodle/lang/en/pagetype.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'pagetype', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   pagetype
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['page-blog-index'] = 'Blog listing pages';
$string['page-blog-x'] = 'All blog pages';
$string['page-course-view-topics'] = 'Any course main page in topics format';
$string['page-course-view-weeks'] = 'Any course main page in weeks format';
$string['page-course-view-x'] = 'Any type of course main page';
$string['page-course-x'] = 'Any course page';
$string['page-mod-x'] = 'Any activity module page';
$string['page-mod-x-view'] = 'Any main activity module page';
$string['page-my-index'] = 'Users\' My home page';
$string['page-site-index'] = 'The front page only';
$string['page-site-x'] = 'Any top-level site page';
$string['page-tag-x'] = 'All tag pages';
$string['page-user-view'] = 'Only user profile pages';
$string['page-user-x'] = 'All user pages';
$string['page-x'] = 'Any page';

==> moodle-2.1.10_20140504.zip: moodle/lang/en/pagetype.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'pagetype', language 'en'
 *
 * @package   pagetype
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['page-admin-current'] = 'The current site administration page';
$string['page-admin-x'] = 'Any site administration page';
$string['page-course-view-x'] = 'Any type of course main page';
$string['page-course-x'] = 'Any course page';
$string['page-course-report-x'] = 'Any course report';
$string['page-mod-x'] = 'Any activity module page';
$string['page-mod-x-view'] = 'Any main activity module page';
$string['page-my-index'] = 'My home page';
$string['page-site-index'] = 'The front page only';
$string['page-site-x'] = 'Any top-level site page';
$string['page-user-view'] = 'Only user profile pages';
$string['page-user-profile'] = 'Only user profile pages';
$string['page-user-x'] = 'All user pages';
$string['page-x'] = 'Any page';
